@@ -5,7 +5,7 @@ from io import BytesIO
 
 import twisted.internet
 from pyppeteer import launch
-from pyppeteer.errors import PageError, TimeoutError
+from pyppeteer.errors import NetworkError, PageError, TimeoutError
 from scrapy.http import HtmlResponse
 from scrapy.utils.python import global_object_name
 from twisted.internet.asyncioreactor import AsyncioSelectorReactor
@@ -150,7 +150,9 @@ class PyppeteerMiddleware(object):
         cls.retry_http_codes = set(int(x)
                                    for x in settings.getlist('RETRY_HTTP_CODES'))
         cls.priority_adjust = settings.getint('RETRY_PRIORITY_ADJUST')
-
+        cls.proxy = settings.get('GERAPY_PYPPETEER_PROXY')
+        cls.proxy_credential = settings.get(
+            'GERAPY_PYPPETEER_PROXY_CREDENTIAL')
         return cls()
 
     async def _process_request(self, request, spider):
@@ -216,16 +218,33 @@ class PyppeteerMiddleware(object):
                 '--disable-blink-features=AutomationControlled')
 
         # set proxy
-        _proxy = request.meta.get('proxy')
+        _proxy = self.proxy
         if pyppeteer_meta.get('proxy') is not None:
             _proxy = pyppeteer_meta.get('proxy')
         if _proxy:
             options['args'].append(f'--proxy-server={_proxy}')
-
         logger.debug('set options %s', options)
 
         browser = await launch(options)
-        page = await browser.newPage()
+        page = None
+
+        try:
+            page = await browser.newPage()
+        except NetworkError:
+            logger.error(
+                'network error occurred while launching pyppeteer page')
+            await page.close()
+            await browser.close()
+            return self._retry(request, 504, spider)
+
+        # set proxy auth credential, see more from
+        # https://pyppeteer.github.io/pyppeteer/reference.html?highlight=auth#pyppeteer.page.Page.authenticate
+        _proxy_credential = self.proxy_credential
+        if pyppeteer_meta.get('proxy_credential') is not None:
+            _proxy_credential = pyppeteer_meta.get('proxy_credential')
+        if _proxy_credential:
+            await page.authenticate(_proxy_credential)
+
         await page.setViewport({'width': self.window_width, 'height': self.window_height})
 
         if _pretend:
